@@ -93,7 +93,7 @@ static guint _last_x = 0;
 
 static gboolean _draw_progressbar_forward = TRUE;
 static gboolean _show_progressbar = FALSE;
-static gboolean _show_textbox_area = FALSE;     /* flag to toggle showing *
+static int	_show_textbox_area = 0;		/* flag to toggle showing *
                                                  * textbox area. @see
                                                  * splashy_function::keyevent_loop() 
                                                  */
@@ -137,7 +137,7 @@ splashy_set_progressbar_visible (gboolean visible)
 }
 
 void
-splashy_set_textbox_area_visible (gboolean visible)
+splashy_set_textbox_area_visible (int visible)
 {
         _show_textbox_area = visible;
         /*
@@ -157,7 +157,7 @@ splashy_set_textbox_area_visible (gboolean visible)
         }
 }
 
-gboolean
+int
 splashy_get_textbox_area_visible (void)
 {
         return _show_textbox_area;
@@ -183,13 +183,13 @@ fb_preinit (struct fb_var_screeninfo *fb_vinfo)
 
         if ((fb_dev_fd = open (fb_dev_name, O_RDWR)) == -1)
         {
-                ERROR_PRINT ("Can't open %s", fb_dev_name);
+                ERROR_PRINT ("libsplashy: Cannot open %s", fb_dev_name);
                 ERROR_PRINT ("%s\n", strerror (errno));
                 goto err_out;
         }
         if (ioctl (fb_dev_fd, FBIOGET_VSCREENINFO, fb_vinfo))
         {
-                ERROR_PRINT ("[fbdev2] Can't get VSCREENINFO: %s\n",
+                ERROR_PRINT ("libsplashy: [fbdev2] Can't get VSCREENINFO: %s\n",
                              strerror (errno));
                 goto err_out;
         }
@@ -409,7 +409,7 @@ draw_progressbar ()
                          rectangle_blue < 0 || rectangle_alpha < 0)
                 {
                         ERROR_PRINT
-                                ("Progress bar border colour not properly specified");
+                                ("libsplashy: Progress bar border color not properly specified");
                 }
                 else
                 {
@@ -441,7 +441,7 @@ draw_progressbar ()
             rectangle_blue > 255 || rectangle_alpha > 255)
         {
                 ERROR_PRINT
-                        ("Red, green, blue or alpha tags in the configuration file contain wrong values");
+                        ("libsplashy: Red, green, blue or alpha tags in the configuration file contain wrong values");
                 return 3;
         }
 
@@ -664,11 +664,9 @@ splashy_update_progressbar_quick (gint perc)
                  */
                 video.primary_surface->FillRectangle (video.
                                                       primary_surface,
-                                                      _w,
+                                                      progressbar->x + (progressbar->w - _w),
                                                       progressbar->y,
-                                                      progressbar->w - (_w -
-                                                                        progressbar->
-                                                                        x),
+                                                      _w,
                                                       progressbar->h);
                 _last_x = progressbar->x + (progressbar->w - _w);
         }
@@ -1104,26 +1102,43 @@ splashy_start_splash ()
         /*
          * initializing Directfb
          */
+        
+        if (DirectFBInit (NULL, NULL) != DFB_OK)
+                return -1;
         /*
          * - no-debug           := suppresses debug messages
          * - quiet              := suppresses all messages (but debug)
          * - graphics-vt        := puts directfb vt in graphics mode
+         *                         text won't display on top of image
          * - no-cursor          := disallow showing a cursor
+         * - vt-num             := puts splashy in vt number 8
+         * - vt                 := in order to use keyboard event buffer
+         *                         we need to dfb to handle vt's
+         * disable modules:
+         * - linux_input        := we loose input from keyboard on dfb 0.9.25
+         * - radeon             := we use fbdev on Linux
          */
-
-        if (DirectFBInit (NULL, NULL) != DFB_OK)
-                return -1;
-
         DirectFBSetOption ("quiet", NULL);
         DirectFBSetOption ("no-debug", NULL);
         DirectFBSetOption ("graphics-vt", NULL);
         DirectFBSetOption ("no-cursor", NULL);
         /*
-         * I disabled these modules, because they were causing problems on my 
-         * machine. 
+         * we want to avoid keyboard problems when running from initramfs
+         * - we tell directfb to use vt 8 instead of 2
          */
-        DirectFBSetOption ("disable-module", "radeon");
-        DirectFBSetOption ("disable-module", "linux_input");
+        DirectFBSetOption ("vt-num", "8");
+        /*
+         * we can't call create_event_buffer() with dfb:no-vt option
+         *
+         *DirectFBSetOption ("no-vt", NULL);*/
+
+         DirectFBSetOption ("disable-module", "radeon");
+        /* 
+         * 2007-12-21 01:14 EST Luis Mondesi
+         * - linux_input looses input on dfb 0.9.25. disabling
+         */
+         DirectFBSetOption ("disable-module", "linux_input");
+         
 
         /*
          * TODO doesn't solve anything: DirectFBSetOption ("dont-catch",
@@ -1135,7 +1150,10 @@ splashy_start_splash ()
 
 
         if (DirectFBCreate (&video.dfb) != DFB_OK)
+        {
+                ERROR_PRINT ("libsplashy: Framebuffer is not configured properly please see %s", "http://tinyurl.com/339h67");
                 return -2;
+        }
 
         video.mode = g_new0 (splashy_videomode_t, 1);
         /*
